==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Bevel/ts/Bevel_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Bevel</name>
    <message>
        <location filename="../Bevel.js" line="+55"/>
        <source>The two entities cannot be bevelled.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Te dwa podmioty nie mogą być frezowane.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>First entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pierwszy podmiot nie może być przycięte.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Second entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Druga jednostka nie może być przycięte.</translation>
    </message>
    <message>
        <location filename="../Bevel.ui" line="+17"/>
        <source>Trim</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zaznacz pierwszy obiekt do przycięcia
Zaznacz drugi obiekt do przycięcia</translatorcomment>
        <translation type="unfinished">Przytnij</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Length 1:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość 1:
Długość 1:</translatorcomment>
        <translation type="unfinished">Długość 1:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Length 2:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość 2:
Długość 2:</translatorcomment>
        <translation type="unfinished">Długość 2:</translation>
    </message>
    <message>
        <location filename="../BevelInit.js" line="+2"/>
        <source>&amp;Chamfer / Bevel</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Ze&amp;tnij</translatorcomment>
        <translation type="unfinished">Ze&amp;tnij</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Bevel/ts/Bevel_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Bevel</name>
    <message>
        <location filename="../Bevel.js" line="+55"/>
        <source>The two entities cannot be bevelled.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie można sfazować wskazanych obiektów.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>First entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie można przyciąć pierwszego obiektu.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Second entity cannot be trimmed.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie można przyciąć drugiego obiektu.</translation>
    </message>
    <message>
        <location filename="../Bevel.ui" line="+17"/>
        <source>Trim</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zaznacz pierwszy obiekt do przycięcia
Zaznacz drugi obiekt do przycięcia</translatorcomment>
        <translation>Przycięcie</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Length 1:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość 1:
Długość 1:</translatorcomment>
        <translation>Długość 1:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Length 2:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość 2:
Długość 2:</translatorcomment>
        <translation>Długość 2:</translation>
    </message>
    <message>
        <location filename="../BevelInit.js" line="+2"/>
        <source>&amp;Chamfer / Bevel</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Ze&amp;tnij</translatorcomment>
        <translation>S&amp;fazuj</translation>
    </message>
</context>
</TS>
